@@ -4,7 +4,6 @@ from .models import contents_manager
 autodiscover()
 
 
-app_name = 'xprez'
+app_name = "xprez"
 
 urlpatterns = [] + contents_manager.get_urls()
-
