@@ -5,7 +5,7 @@ from .settings import XPREZ_BASE_URL, XPREZ_USE_ABSOLUTE_URI
 
 def import_class(cl):
     d = cl.rfind(".")
-    classname = cl[d + 1:len(cl)]
+    classname = cl[d + 1 : len(cl)]
     m = __import__(cl[0:d], globals(), locals(), [classname])
     return getattr(m, classname)
 
@@ -18,10 +18,10 @@ def remove_duplicates(list_):
 
 def build_absolute_uri(location, request=None):
     if XPREZ_USE_ABSOLUTE_URI:
-        if 'http' not in location:
+        if "http" not in location:
             if request:
                 return request.build_absolute_uri(location)
-            return '{}{}'.format(XPREZ_BASE_URL, location)
+            return "{}{}".format(XPREZ_BASE_URL, location)
     return location
 
 
@@ -29,4 +29,4 @@ def random_string(length, include_special_chars=False):
     chars = "abcdefghijklmnopqrstuvwxyz0123456789"
     if include_special_chars:
         chars += "!@#$%^&*(-_=+)"
-    return ''.join([random.choice(chars) for i in range(length)])
+    return "".join([random.choice(chars) for i in range(length)])
